Timing and solver convergence info developed while working on #701 (Add 
support for PETSc solvers)


---------------------
DATA & FILE OVERVIEW
---------------------

```
./
├── README.md
│    { Description of `examples/benchmarking/solvers/`.
├── codes/
│    { Runnable programs
│   ├── loggers/
│   │    { Python logging configuration files.
│   ├── notebooks/
│   │    { [Jupyter](https://jupyter.org/) notebook files.
│   └── scripts/
│        { Python and bash programs.
└── matrices/
    ├── diffusion/
    │    { Simulation results from `codes/scripts/diffusion.py`.
    ├── initial_conditions/
    │    { Restart data for generating illustrative results.
    └── nucleation/
         { Simulation results from `codes/scripts/nucleation.py`.
```

(generated with `tree -FL 2 --info --filesfirst .`)

-------------------------------------
DATA-SPECIFIC INFORMATION FOR: *.info
-------------------------------------

[`tree` command file comment file](https://en.wikipedia.org/wiki/Tree_(command))-formatted text.

--------------------------------------
DATA-SPECIFIC INFORMATION FOR: *.ipynb
--------------------------------------

[Jupyter notebook](https://nbformat.readthedocs.io/en/latest/format_description.html#notebook-file-format)-formatted
text.

-------------------------------------
DATA-SPECIFIC INFORMATION FOR: *.json
-------------------------------------

[JavaScript Object Notation](https://www.json.org/)-formatted text.

-----------------------------------
DATA-SPECIFIC INFORMATION FOR: *.md
-----------------------------------

[Markdown](https://daringfireball.net/projects/markdown/)-formatted text.

------------------------------------
DATA-SPECIFIC INFORMATION FOR: *.npy
------------------------------------

[NumPy array](https://numpy.org/doc/stable/reference/generated/numpy.lib.format.html#module-numpy.lib.format)-formatted
binary.

------------------------------------
DATA-SPECIFIC INFORMATION FOR: *.npz
------------------------------------

A [NumPy zipped archive of files](https://numpy.org/doc/stable/reference/generated/numpy.savez.html)
named after the variables they contain.  The archive is not compressed and
each file in the archive contains one variable in
[`.npy`](https://numpy.org/doc/stable/reference/generated/numpy.lib.format.html#module-numpy.lib.format)
format.

------------------------------------
DATA-SPECIFIC INFORMATION FOR: *.mtx
------------------------------------

[Matrix Market](https://math.nist.gov/MatrixMarket/formats.html)-formatted 
text.

-----------------------------------
DATA-SPECIFIC INFORMATION FOR: *.py
-----------------------------------

[Python code](https://python.org)-formatted text.

-----------------------------------
DATA-SPECIFIC INFORMATION FOR: *.sh
-----------------------------------

[Bash script](https://en.wikipedia.org/wiki/Bash_(Unix_shell))-formatted text.

------------------------------------
DATA-SPECIFIC INFORMATION FOR: *.csv
------------------------------------

Should be `.tsv` or `.csv`?

[Comma-separated value](https://en.wikipedia.org/wiki/Comma-separated_values)-formatted
delimited text.
